<?php
/**
 * WHMC Admin class
 *
 * @author  WPHobby
 * @package WPHobby WooCommerce Mini Cart
 * @version 1.0.0
 */
if( ! class_exists( 'WHMC_Admin' ) ) {
    class WHMC_Admin {
        // =============================================================================
        // Construct
        // =============================================================================
        public function __construct() {
            add_action( 'admin_init', array( $this, 'whmc_register_settings' ) );
            add_action( 'admin_menu', array( $this, 'whmc_register_menu' ) );
            add_action( 'admin_enqueue_scripts', array( $this, 'whmc_admin_styles_scripts' ) );
        }

        /**
         * Load welcome admin css and js
         * @return void
         * @since  1.0.0
         */
        public function whmc_admin_styles_scripts() {
            if ( is_admin() ) {
                wp_enqueue_style('font-awesome', WHMC_URL . 'assets/css/font-awesome.min.css', false, WHMC_VERSION );
                wp_enqueue_style( 'whmc-admin-style', WHMC_URL . 'assets/css/admin.css', false, WHMC_VERSION );

                if( isset( $_GET[ 'tab' ] ) && $_GET[ 'tab' ] == 'custom-style' ){
                    wp_enqueue_script( 'whmc-admin-script', WHMC_URL . 'assets/js/admin.js', array( 'jquery' ), WHMC_VERSION, true );

                    /* Add CodeMirror */
                    $cm_settings['codeEditor'] = wp_enqueue_code_editor(array('type' => 'text/css'));
                    wp_localize_script('jquery', 'cm_settings', $cm_settings);

                    wp_enqueue_script('wp-theme-plugin-editor');
                    wp_enqueue_style('wp-codemirror');
                }

            }
        }

        /*
         * Display admin messages
         */
        public function whmc_display_message(){
            if ( isset( $_GET['settings-updated'] ) ) {
                echo "<div class='updated'><p>".__( 'Settings updated successfully.', 'woo-mini-cart' )."</p></div>";
            }
        }

        /**
         * Register admin menus
         * @return void
         * @since  1.0.0
         */
        public function whmc_register_menu(){
            add_menu_page( 'WPHobby WooCommerce Mini Cart', 'Mini Cart', 'manage_options', 'whmc-panel', array( $this, 'whmc_panel_general' ), WHMC_URL . '/assets/images/icon.svg', '2');
            add_submenu_page('whmc-panel', 'Help & Guide', 'Help & Guide', 'manage_options', 'whmc-help', array( $this, 'whmc_panel_help' ) );
        }

        /**
         * The admin panel content
         * @since 1.0.0
         */
        public function whmc_panel_general() {
            $active_tab = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'general';
            ?>
            <div class="whmc-panel">
                <div class="wrap">
                    <?php require_once( WHMC_DIR . '/includes/admin/sections/general/top.php' ); ?>
                    <?php $this->whmc_display_message(); ?>
                    <?php
                    if( $active_tab == 'general' ){
                        require_once( WHMC_DIR . '/includes/admin/sections/general/tab-general.php' );
                    }else if($active_tab == 'advanced'){
                        require_once( WHMC_DIR . '/includes/admin/sections/general/tab-advanced.php' );
                    }else if($active_tab == 'server'){
                        require_once( WHMC_DIR . '/includes/admin/sections/general/tab-server.php' );
                    }else if($active_tab == 'custom-style'){
                        require_once( WHMC_DIR . '/includes/admin/sections/general/tab-custom-style.php' );
                    }
                    ?>
                </div>
            </div>
            <?php
        }

        /**
         * The admin panel help
         * @since 1.0.0
         */
        public function whmc_panel_help() {
            $active_tab = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'help';
            ?>
            <div class="whmc-panel">
                <div class="wrap">
                    <?php require_once( WHMC_DIR . '/includes/admin/sections/help/top.php' ); ?>
                    <?php $this->whmc_display_message(); ?>
                    <?php
                    if( $active_tab == 'help' ){
                        require_once( WHMC_DIR . '/includes/admin/sections/help/tab-help.php' );
                    }else if($active_tab == 'change-log'){
                        require_once( WHMC_DIR . '/includes/admin/sections/help/tab-change-log.php' );
                    }
                    ?>
                </div>
            </div>
            <?php
        }

        /**
         * Register Settings
         * @since 1.0.0
         */
        public function whmc_register_settings() {
            register_setting(
                'whmc_advanced', // A settings group name. Must exist prior to the register_setting call. This must match the group name in settings_fields()
                'whmc_advanced_data' //The name of an option to sanitize and save.
            );

            register_setting(
                'whmc_general', // A settings group name. Must exist prior to the register_setting call. This must match the group name in settings_fields()
                'whmc_general_data'
            );

            register_setting(
                'whmc_custom', // A settings group name. Must exist prior to the register_setting call. This must match the group name in settings_fields()
                'whmc_custom_data'
            );

            add_settings_section( 'whmc_section_general', '', array( $this, 'whmc_section_general_output' ), 'whmc_panel_general' );
            add_settings_field( 'whmc_field_cart_position', esc_html__("Mini Cart Position", "woo-mini-cart"), array( $this, 'whmc_cart_position_output' ), 'whmc_panel_general', 'whmc_section_general' );
            add_settings_field( 'whmc_field_cart_icon', esc_html__("Display Shop Cart Icon", "woo-mini-cart"), array( $this, 'whmc_cart_icon_output' ), 'whmc_panel_general', 'whmc_section_general' );

            add_settings_section( 'whmc_section_custom_style', '', array( $this, 'whmc_section_custom_style_output' ), 'whmc_panel_custom_style' );
            add_settings_field( 'whmc_field_custom_css', esc_html__("Custom CSS", "woo-mini-cart"), array( $this, 'whmc_custom_css_output' ), 'whmc_panel_custom_style', 'whmc_section_custom_style' );

            add_settings_section( 'whmc_section_advanced', '', array( $this, 'whmc_section_advanced_output' ), 'whmc_panel_advanced' );
            add_settings_field( 'whmc_field_cart_message', esc_html__("Display Add to Cart Message", "woo-mini-cart"), array( $this, 'whmc_cart_message_output' ), 'whmc_panel_advanced', 'whmc_section_advanced' );
            add_settings_field( 'whmc_field_prompt_message', esc_html__("Prompt Message", "woo-mini-cart"), array( $this, 'whmc_prompt_message_output' ), 'whmc_panel_advanced', 'whmc_section_advanced' );


        }

        public function whmc_section_general_output() {
            echo esc_html__( 'This is where general display settings.', 'woo-mini-cart' );
        }

        public function whmc_cart_position_output() {
            $options = get_option( 'whmc_general_data' );
            ?>
            <select name='whmc_general_data[whmc_field_cart_position]'> 
                <option value='left' <?php if(isset($options['whmc_field_cart_position'])){selected( $options['whmc_field_cart_position'], 'left' );} ?>>Left</option> 
                <option value='right' <?php if(isset($options['whmc_field_cart_position'])){selected( $options['whmc_field_cart_position'], 'right' );} ?>>Right</option> 
            </select>
            <?php
        }

        public function whmc_cart_icon_output() {
            $options = get_option( 'whmc_general_data' );
            $value = 1;
            $checked = $options['whmc_field_cart_icon']== '1' ? 'checked' : '';
            ?>
            <label class="switch">
                <input type="checkbox" value='<?php echo esc_attr($value); ?>' name='whmc_general_data[whmc_field_cart_icon]' <?php echo esc_attr($checked); ?> />
                <span class="slider round"></span>
            </label>
            <?php
        }

        public function whmc_section_custom_style_output() {
            echo esc_html__( 'Add your on custom css code.', 'woo-mini-cart' );
        }

        public function whmc_custom_css_output() {
            $options = get_option( 'whmc_custom_data' );
            ?>
            <textarea id="fancy-textarea" name="whmc_custom_data[whmc_field_custom_css]"><?php echo esc_html($options['whmc_field_custom_css']);?></textarea>
            <?php
        }

        public function whmc_section_advanced_output() {
            echo esc_html__( 'Advanced Settings for Mini Cart Message.', 'woo-mini-cart' );
        }

        public function whmc_cart_message_output() {
            $options = get_option( 'whmc_advanced_data' );
            $value = 1;
            $checked = $options['whmc_field_cart_message']== '1' ? 'checked' : '';
            ?>
            <label class="switch">
                <input type="checkbox" value='<?php echo esc_attr($value); ?>' name='whmc_advanced_data[whmc_field_cart_message]' <?php echo esc_attr($checked); ?> />
                <span class="slider round"></span>
            </label>
            <?php
        }

        public function whmc_prompt_message_output() {
            $options = get_option( 'whmc_advanced_data' );
            ?>
            <input type="text" name="whmc_advanced_data[whmc_field_prompt_message]" value='<?php echo esc_attr($options['whmc_field_prompt_message']); ?>'/>
            <?php
        }


    }

    new WHMC_Admin;
}